==> hoteldruid-mod-fr_2.2.2-1.tar.gz: fr/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":	  		$messaggio = "Le nom de famille sera changé par"; break;
case "a":  										$messaggio = "à"; break;
case "Il nome verrà cambiato da":  				$messaggio = "Le prénom sera changé par"; break;
case "Il sesso verrà cambiato a":  				$messaggio = "Le genre sera changé à "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "La date de naissance sera changé par"; break;
case "Il telefono verrà cambiato da": 	 		$messaggio = "Le téléphone sera changé par"; break;
case "La via  verrà cambiata da":  				$messaggio = "La rue sera changé par"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Le numéro de la rue sera changé par"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "La ville sera changé par"; break;
case "Il CAP verrà cambiato da":  				$messaggio = "Le code postal sera changé par"; break;
case "Il fax verrà cambiato da":  				$messaggio = "Le fax sera changé par"; break;
case "L' email verrà cambiata da":  			$messaggio = "L'email sera changé par"; break;
case "Il 2° telefono verrà cambiato da": 	 	$messaggio = "Le 2ème téléphone sera changé par"; break;
case "Il 3° telefono verrà cambiato da":  		$messaggio = "Le 3ème téléphone sera changé par"; break;
case "Il <b>commento</b> verrà cambiato": $messaggio = "Le <b>commentaire</b> sera changé"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "Le <b>prénom</b> sera supprimé"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "The <b>birthday</b> will be deleted"; break;
case "Il <b>telefono</b> verrà cancellato":  		$messaggio = "Le <b>téléphone</b> sera supprimé"; break;
case "La <b>via</b> verrà cancellata":  			$messaggio = "La <b>rue</b> sera supprimé"; break;
case "Il <b>n° civico</b> verrà cancellato": 		$messaggio = "Le <b>numéro de la rue</b> sera supprimé"; break;
case "Il <b>CAP</b> verrà cancellato":  			$messaggio = "Le <b>code postal</b> sera supprimé"; break;
case "Il <b>fax</b> verrà cancellato":  			$messaggio = "Le <b>fax</b> sera supprimé"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Le <b>2ème téléphone</b> sera supprimé"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Le <b>3ème téléphone</b> sera supprimé"; break;
case "Continua":  					$messaggio = "Continuez"; break;
case "è stato modificato":  		$messaggio = "a été modifié"; break;
case "Torna indietro":  			$messaggio = "Retournez"; break;
case "Modifica i dati del cliente":	$messaggio = "Modifiez les données du client"; break;
case "Cognome":  					$messaggio = "Nom"; break;
case "cambia in":  					$messaggio = "changez en"; break;
case "Nome":  						$messaggio = "Prénom"; break;
case "cancella":  					$messaggio = "supprimez"; break;
case "Sesso":  						$messaggio = "Genre"; break;
case "Data di nascita":  			$messaggio = "Date de naissance"; break;
case "Telefono":  					$messaggio = "Téléphone"; break;
case "Via":  						$messaggio = "Rue"; break;
case "Vicolo":  					$messaggio = "Ruelle"; break;
case "Numero civico":  				$messaggio = "Numéro"; break;
case "CAP":  						$messaggio = "Code Postal"; break;
case "Fax":  						$messaggio = "Fax"; break;
case "2° telefono":  				$messaggio = "2ème téléphone"; break;
case "3° telefono":  				$messaggio = "3ème téléphone"; break;
case "Commento":  					$messaggio = "Commentaire"; break;
case "Prenotazioni del cliente":  	$messaggio = "Réservations du client"; break;
case "nel":  						$messaggio = "en"; break;
case "Cognome_del_cliente":  		$messaggio = "Nom du client"; break;
case "Data_iniziale":  				$messaggio = "Date début"; break;
case "Data_finale":  				$messaggio = "Date fin"; break;
case "Tariffa_completa":  			$messaggio = "Prix Complet"; break;
case "Caparra":  					$messaggio = "Accompte"; break;
case "Pagato":  					$messaggio = "Payé"; break;
case "Commento":  					$messaggio = "Commentaire"; break;
case "Pers":  						$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Inséré par"; break;
case "Si considererà l'utente":  	$messaggio = "Utilisateur"; break;
case "come colui che ha inserito il cliente":	$messaggio = "sera considéré en tant que celui qui a inséré le client"; break;
case "Cliente cancellato":  		$messaggio = "Client supprimé"; break;
case "Cancella il cliente":  		$messaggio = "Supprimer le client"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Ce client ne peut pas être supprimé parce qu'il est encore associé à des réservations"; break;
case "NO":  						$messaggio = "NON"; break;
case "SI":  						$messaggio = "OUI"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il cliente":  				$messaggio = "Client"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Città di residenza":  			$messaggio = "City of residence"; break;
case "Nazione di residenza":  			$messaggio = "Nation of residence"; break;
case "Email":  					$messaggio = "Email"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\">delete</div> client"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region of residence"; break;
case "Documento":  				$messaggio = "Document"; break;
case "Scadenza documento":  			$messaggio = "Document expiration"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "Il documento verrà cambiato da":  	$messaggio = "The document will be changed from"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "The document expiration date will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>document</b> will be deleted"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "The <b>document expiration date</b> will be deleted"; break;
case "Cittadinanza":  				$messaggio = "Nationality"; break;
case "Nazione di nascita":  			$messaggio = "Nation of birth"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Region of birth"; break;
case "Città di nascita":  			$messaggio = "City of birth"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "Nazione di rilascio":  			$messaggio = "Releasing nation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":	  		$messaggio = "Le nom de famille sera changé par"; break;
case "a":  										$messaggio = "à"; break;
case "Il nome verrà cambiato da":  				$messaggio = "Le prénom sera changé par"; break;
case "Il sesso verrà cambiato a":  				$messaggio = "Le genre sera changé à "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "La date de naissance sera changé par"; break;
case "Il telefono verrà cambiato da": 	 		$messaggio = "Le téléphone sera changé par"; break;
case "La via  verrà cambiata da":  				$messaggio = "La rue sera changé par"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Le numéro de la rue sera changé par"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "La ville sera changé par"; break;
case "Il CAP verrà cambiato da":  				$messaggio = "Le code postal sera changé par"; break;
case "Il fax verrà cambiato da":  				$messaggio = "Le fax sera changé par"; break;
case "L' email verrà cambiata da":  			$messaggio = "L'email sera changé par"; break;
case "Il 2° telefono verrà cambiato da": 	 	$messaggio = "Le 2ème téléphone sera changé par"; break;
case "Il 3° telefono verrà cambiato da":  		$messaggio = "Le 3ème téléphone sera changé par"; break;
case "Il <b>commento</b> verrà cambiato": $messaggio = "Le <b>commentaire</b> sera changé"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "Le <b>prénom</b> sera supprimé"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "The <b>birthday</b> will be deleted"; break;
case "Il <b>telefono</b> verrà cancellato":  		$messaggio = "Le <b>téléphone</b> sera supprimé"; break;
case "La <b>via</b> verrà cancellata":  			$messaggio = "La <b>rue</b> sera supprimé"; break;
case "Il <b>n° civico</b> verrà cancellato": 		$messaggio = "Le <b>numéro de la rue</b> sera supprimé"; break;
case "Il <b>CAP</b> verrà cancellato":  			$messaggio = "Le <b>code postal</b> sera supprimé"; break;
case "Il <b>fax</b> verrà cancellato":  			$messaggio = "Le <b>fax</b> sera supprimé"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Le <b>2ème téléphone</b> sera supprimé"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Le <b>3ème téléphone</b> sera supprimé"; break;
case "Continua":  					$messaggio = "Continuez"; break;
case "è stato modificato":  		$messaggio = "a été modifié"; break;
case "Torna indietro":  			$messaggio = "Retournez"; break;
case "Modifica i dati del cliente":	$messaggio = "Modifiez les données du client"; break;
case "Cognome":  					$messaggio = "Nom"; break;
case "cambia in":  					$messaggio = "changez en"; break;
case "Nome":  						$messaggio = "Prénom"; break;
case "cancella":  					$messaggio = "supprimez"; break;
case "Sesso":  						$messaggio = "Genre"; break;
case "Data di nascita":  			$messaggio = "Date de naissance"; break;
case "Telefono":  					$messaggio = "Téléphone"; break;
case "Via":  						$messaggio = "Rue"; break;
case "Vicolo":  					$messaggio = "Ruelle"; break;
case "Numero civico":  				$messaggio = "Numéro"; break;
case "CAP":  						$messaggio = "Code Postal"; break;
case "Fax":  						$messaggio = "Fax"; break;
case "2° telefono":  				$messaggio = "2ème téléphone"; break;
case "3° telefono":  				$messaggio = "3ème téléphone"; break;
case "Commento":  					$messaggio = "Commentaire"; break;
case "Prenotazioni del cliente":  	$messaggio = "Réservations du client"; break;
case "nel":  						$messaggio = "en"; break;
case "Cognome_del_cliente":  		$messaggio = "Nom du client"; break;
case "Data_iniziale":  				$messaggio = "Date début"; break;
case "Data_finale":  				$messaggio = "Date fin"; break;
case "Tariffa_completa":  			$messaggio = "Prix Complet"; break;
case "Caparra":  					$messaggio = "Accompte"; break;
case "Pagato":  					$messaggio = "Payé"; break;
case "Commento":  					$messaggio = "Commentaire"; break;
case "Pers":  						$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Inséré par"; break;
case "Si considererà l'utente":  	$messaggio = "Utilisateur"; break;
case "come colui che ha inserito il cliente":	$messaggio = "sera considéré en tant que celui qui a inséré le client"; break;
case "Cliente cancellato":  		$messaggio = "Client supprimé"; break;
case "Cancella il cliente":  		$messaggio = "Supprimer le client"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Ce client ne peut pas être supprimé parce qu'il est encore associé à des réservations"; break;
case "NO":  						$messaggio = "NON"; break;
case "SI":  						$messaggio = "OUI"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il cliente":  				$messaggio = "Client"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Città di residenza":  			$messaggio = "City of residence"; break;
case "Nazione di residenza":  			$messaggio = "Nation of residence"; break;
case "Email":  					$messaggio = "Email"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\">delete</div> client"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region of residence"; break;
case "Documento":  				$messaggio = "Document"; break;
case "Scadenza documento":  			$messaggio = "Document expiration"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "Il documento verrà cambiato da":  	$messaggio = "The document will be changed from"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "The document expiration date will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>document</b> will be deleted"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "The <b>document expiration date</b> will be deleted"; break;
case "Cittadinanza":  				$messaggio = "Nationality"; break;
case "Nazione di nascita":  			$messaggio = "Nation of birth"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Region of birth"; break;
case "Città di nascita":  			$messaggio = "City of birth"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "Nazione di rilascio":  			$messaggio = "Releasing nation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
